@@ -100,6 +100,9 @@ class NumpyBackend(Backend):
     float = numpy.float64
     """ floating type for array """
 
+    complex = numpy.complex128
+    """ complex type for array """
+
     # methods
     asarray = _replace_float(numpy.asarray)
 
@@ -186,6 +189,15 @@ class NumpyBackend(Backend):
     numpy = _replace_float(numpy.asarray)
     """ convert the array to numpy array """
 
+    @staticmethod
+    def is_complex(x):
+        """check if an object is a `ComplexFloat`"""
+
+        return isinstance(x, complex) or (
+            isinstance(x, numpy.ndarray)
+            and x.dtype in (numpy.complex64, numpy.complex128)
+        )
+
 
 # Torch Backend
 if TORCH_AVAILABLE:
@@ -201,6 +213,12 @@ if TORCH_AVAILABLE:
         float = torch.get_default_dtype()
         """ floating type for array """
 
+        if float is torch.float32:
+            complex = torch.complex64
+        else:
+            complex = torch.complex128
+        """ complex type for array """
+
         # methods
         asarray = staticmethod(torch.as_tensor)
         """ create an array """
@@ -296,6 +314,8 @@ if TORCH_AVAILABLE:
             else:
                 return numpy.asarray(arr)
 
+        is_complex = staticmethod(torch.is_complex)
+
     # Torch Cuda Backend
     if TORCH_CUDA_AVAILABLE:
 
