@@ -37,7 +37,7 @@ def curl_E(E: Tensorlike) -> Tensorlike:
     Returns:
         The curl of E (H-type field located on the faces of the grid [half-integer grid points])
     """
-    curl = bd.zeros(E.shape)
+    curl = bd.zeros(E.shape,dtype=E.dtype)
 
     curl[:, :-1, :, 0] += E[:, 1:, :, 2] - E[:, :-1, :, 2]
     curl[:, :, :-1, 0] -= E[:, :, 1:, 1] - E[:, :, :-1, 1]
@@ -62,7 +62,7 @@ def curl_H(H: Tensorlike) -> Tensorlike:
         The curl of H (E-type field located on the edges of the grid [integer grid points])
 
     """
-    curl = bd.zeros(H.shape)
+    curl = bd.zeros(H.shape,dtype=H.dtype)
 
     curl[:, 1:, :, 0] += H[:, 1:, :, 2] - H[:, :-1, :, 2]
     curl[:, :, 1:, 0] -= H[:, :, 1:, 1] - H[:, :, :-1, 1]
@@ -263,7 +263,7 @@ class Grid:
             time = tqdm(time)
         for _ in time:
             self.step()
-
+    
     def step(self):
         """do a single FDTD step by first updating the electric field and then
         updating the magnetic field
@@ -349,6 +349,11 @@ class Grid:
         """add an object to the grid"""
         obj._register_grid(self)
         self.objects[name] = obj
+    
+    def promote_dtypes_to_complex(self):
+        self.E = self.E.astype(bd.complex)
+        self.H = self.H.astype(bd.complex)
+        [boundary.promote_dtypes_to_complex() for boundary in self.boundaries]
 
     def __setitem__(self, key, attr):
         if not isinstance(key, tuple):
